<template>
  <span>
    <h4
      class="card-title"
      :class="$i18n.locale == 'ar' ? 'font-size-15' : 'txt-left'"
    >
      {{ $t("view.location") }}
    </h4>
    <div class="col-12 input-group pd-0" style="padding: 0">
      <CardSelect
        class="col-12"
        style="padding: 0"
        :select_id="row.country_id"
        refs="countries"
        :label="$t('nav.countries')"
        @selectChange="handleCountryChange"
      />

      <CardSelect
        class="col-12"
        style="padding: 0"
        :select_id="row.government_id"
        refs="governments"
        :bus="bus"
        :label="$t('nav.governments')"
        v-if="row.country_id"
        @selectChange="handleGovernmentChange"
      />

      <CardSelect
        class="col-12"
        style="padding: 0"
        :select_id="row.city_id"
        refs="cities"
        :bus="bus2"
        :label="$t('nav.cities')"
        v-if="row.government_id"
        @selectChange="handleCityChange"
      />

      <CardSelect
        class="col-12"
        style="padding: 0"
        :select_id="row.piece_id"
        refs="pieces"
        :bus="bus3"
        :label="$t('nav.pieces')"
        v-if="row.city_id"
        @selectChange="handlePieceChange"
      />

      <CardInput
        class="col-12"
        style="padding: 0"
        :label="$t('view.street')"
        :input="row.street"
        @inputChange="handleStreetChange"
      />

      <CardInput
        class="col-12"
        style="padding: 0"
        :label="$t('view.location_link')"
        :input="row.location_link"
        @inputChange="handleLocationLinkChange"
      />
    </div>
  </span>
</template>

<script>
import Vue from "vue";
import CardSelect from "@/components/CardSelect";
import CardInput from "@/components/CardInput";

export default {
  name: "CardLocation",
  components: { CardInput, CardSelect },
  props: [
    "country_id",
    "government_id",
    "city_id",
    "piece_id",
    "street",
    "location_link",
  ],
  data() {
    return {
      bus: new Vue(),
      bus2: new Vue(),
      bus3: new Vue(),
      row: {
        country_id: this.$props.country_id,
        government_id: this.$props.government_id,
        city_id: this.$props.city_id,
        piece_id: this.$props.piece_id,
        location_link: this.$props.location_link,
        street: this.$props.street,
      },
    };
  },
  methods: {
    handleCountryChange(event) {
      this.row.country_id = event.select_id;
      this.onChange();
      this.bus.$emit("parent_changed", event.select_id);
    },
    handleGovernmentChange(event) {
      this.row.government_id = event.select_id;
      this.onChange();
      this.bus2.$emit("parent_changed", event.select_id);
    },
    handleCityChange(event) {
      this.row.city_id = event.select_id;
      this.onChange();
      this.bus3.$emit("parent_changed", event.select_id);
    },
    handlePieceChange(event) {
      this.row.piece_id = event.select_id;
      this.onChange();
    },
    handleStreetChange(event) {
      this.row.street = event.input;
      this.onChange();
    },
    handleLocationLinkChange(event) {
      this.row.location_link = event.input;
      this.onChange();
    },
    onChange() {
      this.$emit("locationChange", this.row);
    },
  },
};
</script>
